Tutorial
========

This page is a tutorial introduction to ``gcmpy``. It begins with an overview of the
workflow structure of the library before building sequentially more complicated
network examples. 


.. toctree::
    :maxdepth: 2

    tutorial/getting_started.rst
    tutorial/from_marginal.rst
    tutorial/from_empirical_data.rst
    tutorial/split_degree.rst
    tutorial/from_clique_cover.rst